@@ -18,6 +18,20 @@ def badcommand(msg):
     """(Parsing error) print to stderr and quit."""
     fatalerror(msg, label='usage', code=2)
 
+class doing:
+    """``with`` wrapper for messages like "Doing X... Done.\""""
+
+    done = ' Done.'
+
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __enter__(self):
+        echo(self.msg + '...', width=72 - len(self.done), end='', flush=True)
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        echo(self.done)
+
 
 def echo(text, width=72, **kwargs):
     """``print()``, but wraps long lines, preserving the initial indent."""
@@ -49,7 +63,7 @@ def failcheck(msg):
 
 def fatalerror(msg, label='error', code=1):
     """Print to stderr and quit."""
-    id_msg = ': '.join(('vnv', label, msg)) # Identify vnv.
+    id_msg = ': '.join(('vnv', label, msg))  # Identify vnv.
     echo(id_msg, file=sys.stderr)
     sys.exit(code)
 
@@ -100,7 +114,7 @@ class CLI:
         self.shell = shellmap.get(args.pop(0)) if args else None
         if self.shell is None:
             badcommand('vnv.cli should not be used directly.\nTry "vnv".')
-        self.raw_args = tuple(args) # Used for forwarding
+        self.raw_args = tuple(args)  # Used for forwarding
         # Instantiate each Command subclass with a reference to the CLI.
         cmds = (Class(self) for Class in Command.__subclasses__())
         self.commands = {cmd.name: cmd for cmd in cmds}
@@ -169,7 +183,7 @@ Available subcommands:"""
         else:
             # No args, inactive, so try to activate from cache.
             cached = os.getenv(vnv_cache)
-            if not cached: # Could be None or ''
+            if not cached:  # Could be None or ''
                 fatalerror('No env cached.'
                            '\nTry "vnv --help" for more information.')
             actfile = self.cli.pathm.get_actfile(Path(cached))
@@ -219,9 +233,8 @@ To create "my-venv" in the current directory, make sure to use:
             fatalerror('Cannot access virtualenv. Is it installed?')
         # Account for the possiblility of a -- coming before ENV.
         subsequent_args = self.cli.raw_args[2 if self.cli.mixedargs else 3:]
-        echo(f'Creating virtual environment at "{env}"...')
-        virtualenv.cli_run([env, *subsequent_args])
-        echo('Done.')
+        with doing(f'Creating virtualenv at "{env}"'):
+            virtualenv.cli_run([env, *subsequent_args])
 
 
 class DelCommand(Command):
@@ -243,9 +256,8 @@ Use "vnv -which ENV" to confirm which folder that is."""
             actfile = self.cli.pathm.lookup(env)
             if actfile is not None:
                 env_folder = actfile.parents[1]
-                echo(f'Deleting env "{env_folder}"...')
-                shutil.rmtree(env_folder)
-                echo('Done.')
+                with doing(f'Deleting env "{env_folder}"'):
+                    shutil.rmtree(env_folder)
             else:
                 fatalerror(envnotfound(env))
 
@@ -258,10 +270,10 @@ class ListCommand(Command):
 Usage:
     vnv -list [-n | -p]
 
-List all envs on the vnv path.  See "vnv -path --help" for more
+List all envs on the vnv path. See "vnv -path --help" for more
 information.
 
-If -n is given, only print env names, each on its own line.  If -p is
+If -n is given, only print env names, each on its own line. If -p is
 given, do the same with env paths."""
 
     def __call__(self):
@@ -294,7 +306,7 @@ class WhichCommand(Command):
 Usage:
     vnv -which [ENV]
 
-Print the location of ENV, if specified.  If not, print the location of
+Print the location of ENV, if specified. If not, print the location of
 the cached env.
 
 Use this to see what ENV resolves to, or to check the cached env (also
@@ -314,7 +326,7 @@ stored in {self.cli.shell.exported % vnv_cache})."""
         else:
             # Print $VNV_CACHE.
             cached = os.getenv(vnv_cache)
-            if cached: # Could be None or ''
+            if cached:  # Could be None or ''
                 echo(cached)
             else:
                 failcheck('No env cached.')
@@ -334,11 +346,11 @@ Usage:
 Display or modify your vnv path.
 
 If you keep your installed envs in a folder somewhere, the vnv path is
-how to tell vnv about it.  The vnv path includes the internal envs
-folder and any newline-separated paths in "{tilde(path_file)}".
+how to tell vnv about it. The vnv path includes the internal envs folder
+and any newline-separated paths in "{tilde(path_file)}".
 
 When given a name like "my-venv", vnv will only look for it on the vnv
-path.  To specify that "my-venv" is in the current directory, use the
+path. To specify that "my-venv" is in the current directory, use the
 path "./my-venv" instead.
 
 vnv only finds envs that your shell can activate.
@@ -347,10 +359,10 @@ vnv -path
     Displays your vnv path.
 
 vnv -path -add [-r] [N] DIR
-    Adds DIR to {path_file.name}, at position N (if specified).  If -r is\
- given, DIR will not be resolved to an absolute path, allowing it to be\
- relative to wherever vnv is run.  Since {tilde(internal_dir)} is always #0, N\
- must be 1 or more.
+    Adds DIR to {path_file.name}, at position N (if specified). If -r is \
+given, DIR will not be resolved to an absolute path, allowing it to be \
+relative to wherever vnv is run. Since {tilde(internal_dir)} is always #0, N \
+must be 1 or more.
 
 vnv -path -pop N...
     Removes dir(s) by number.
@@ -400,35 +412,25 @@ You can always just go edit {path_file.name} yourself."""
         new_vnv_path = list(self.cli.pathm.raw)
         new_vnv_path.insert(n - 1, path_str)
         write_path_file(new_vnv_path)
-        echo(f'Added {path_str!r} to vnv path.')
 
     def pop(self):
         """$ vnv -path -pop N..."""
         new_vnv_path = list(self.cli.pathm.raw)
         for n in self.parse_ns():
             entry = self.cli.pathm.raw[n - 1]
-            echo(f'Removing {entry!r} from vnv path...')
             new_vnv_path.remove(entry)
         write_path_file(new_vnv_path)
-        echo('Done.')
 
     def order(self):
         """$ vnv -path -order N..."""
         old_vnv_path = list(self.cli.pathm.raw)
         new_vnv_path = []
-        first = True
         for n in self.parse_ns():
             entry = self.cli.pathm.raw[n - 1]
-            if first:
-                echo(f'Bringing {entry!r} to front...')
-                first = False
-            else:
-                echo(f'Then {entry!r}...')
             new_vnv_path.append(entry)
             old_vnv_path[n - 1] = None
         new_vnv_path.extend(i for i in old_vnv_path if i is not None)
         write_path_file(new_vnv_path)
-        echo('Done.')
 
     def parse_ns(self):
         """For -path -pop and -path -order, parse all those Ns."""
